# w.c.s. - web application for online forms
# Copyright (C) 2005-2010  Entr'ouvert
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301  USA

import time
import sys
import os

from qommon.ctl import Command, make_option

def rebuild_vhost_indexes(destroy=False):
    from wcs.formdef import FormDef
    if destroy:
        FormDef.destroy_indexes()
    FormDef.rebuild_indexes()
    from wcs.users import User
    if destroy:
        User.destroy_indexes()
    User.rebuild_indexes()


class CmdRebuildIndexes(Command):
    name = 'rebuild_indexes'

    def __init__(self):
        Command.__init__(self, [
                make_option('--all', action='store_true',
                            dest='all', default=False),
                make_option('--destroy', action='store_true',
                            dest='destroy', default=False),
                make_option('--extra', metavar='DIR', action='append',
                            dest='extra', default=[]),
                ])

    def execute(self, options, args):
        import publisher

        for directory in options.extra:
            publisher.WcsPublisher.register_extra_dir(directory)

        pub = publisher.WcsPublisher.create_publisher()

        app_dir = pub.app_dir
        if options.all:
            hostnames = os.listdir(app_dir)
        else:
            hostnames = args
        for hostname in hostnames:
            pub.app_dir = os.path.join(app_dir, hostname)
            rebuild_vhost_indexes(destroy=options.destroy)

CmdRebuildIndexes.register()
